export declare const schema: {
    $id: string;
    name: string;
    type: string;
    required: string[];
    properties: {
        id: {
            type: string;
            title: string;
            ui: {
                "ui:autofocus": boolean;
                "ui:placeholder": string;
            };
        };
        name: {
            type: string;
            title: string;
            ui: {
                "ui:placeholder": string;
            };
        };
        $template: {
            type: string;
            title: string;
            ui: {
                classNames: string;
            };
            properties: {
                name: {
                    type: string;
                    title: string;
                    ui: {
                        "ui:placeholder": string;
                    };
                };
                type: {
                    type: string;
                    title: string;
                    default: string;
                    enum: string[];
                };
                url: {
                    type: string;
                    title: string;
                    ui: {
                        "ui:placeholder": string;
                    };
                };
            };
            required: string[];
        };
        issuers: {
            type: string;
            title: string;
            minItems: number;
            ui: {
                "ui:options": {
                    orderable: boolean;
                };
                classNames: string;
            };
            items: {
                type: string;
                properties: {
                    name: {
                        type: string;
                        title: string;
                    };
                    documentStore: {
                        type: string;
                        title: string;
                        pattern: string;
                        ui: {
                            "ui:placeholder": string;
                        };
                    };
                    identityProof: {
                        type: string;
                        title: string;
                        properties: {
                            type: {
                                type: string;
                                title: string;
                                default: string;
                                enum: string[];
                            };
                            location: {
                                type: string;
                                title: string;
                                ui: {
                                    "ui:placeholder": string;
                                };
                            };
                        };
                        required: string[];
                    };
                };
            };
        };
        consignee: {
            type: string;
            title: string;
            ui: {
                classNames: string;
            };
            properties: {
                name: {
                    type: string;
                    title: string;
                };
                type: {
                    type: string;
                    title: string;
                };
            };
        };
        notifyParty: {
            type: string;
            title: string;
            ui: {
                classNames: string;
            };
            properties: {
                name: {
                    type: string;
                    title: string;
                };
            };
        };
        shipper: {
            type: string;
            title: string;
            ui: {
                classNames: string;
            };
            properties: {
                name: {
                    type: string;
                    title: string;
                };
                address: {
                    type: string;
                    title: string;
                    properties: {
                        street: {
                            type: string;
                            title: string;
                        };
                        country: {
                            type: string;
                            title: string;
                        };
                    };
                };
            };
        };
        vessel: {
            type: string;
            title: string;
        };
        voyageNo: {
            type: string;
            title: string;
        };
        portOfLoading: {
            type: string;
            title: string;
        };
        portOfDischarge: {
            type: string;
            title: string;
        };
        placeOfReceipt: {
            type: string;
            title: string;
        };
        placeOfDelivery: {
            type: string;
            title: string;
        };
        packages: {
            type: string;
            title: string;
            ui: {
                "ui:options": {
                    orderable: boolean;
                };
                classNames: string;
            };
            items: {
                type: string;
                properties: {
                    description: {
                        type: string;
                        title: string;
                    };
                    weight: {
                        type: string;
                        title: string;
                        ui: {
                            "ui:help": string;
                        };
                    };
                    measurement: {
                        type: string;
                        title: string;
                    };
                };
            };
        };
    };
}[];
export declare const data: {
    id: string;
    name: string;
    $template: {
        name: string;
        url: string;
    };
    issuers: {
        name: string;
        documentStore: string;
        identityProof: {
            type: string;
            location: string;
        };
    }[];
    consignee: {
        name: string;
        type: string;
    };
    notifyParty: {
        name: string;
    };
    shipper: {
        name: string;
        address: {
            street: string;
            country: string;
        };
    };
    vessel: string;
    voyageNo: number;
    portOfLoading: string;
    portOfDischarge: string;
    placeOfReceipt: string;
    placeOfDelivery: string;
    packages: {
        description: string;
        weight: number;
        measurement: string;
    }[];
}[];
